@@ -4,7 +4,7 @@
 #
 # Updates:
 # 29-Sep-2022: zf added 'auth_numbering' as 4th value in seqTuple for coodinate sequence in __generateInputSeqInfoForPseudoMultiAlignFromSeqList() method.
-#              added self.__conflictMap dictionary and wtite out self.__conflictMap pickle file for new entity summary page.
+#              added self.__conflictMap for new entity summary page.
 #
 """
 Methods to manage sequence alignments.
@@ -15,12 +15,6 @@ __email__ = "zfeng@rcsb.rutgers.edu"
 __license__ = "Creative Commons Attribution 3.0 Unported"
 __version__ = "V0.09"
 
-try:
-    import cPickle as pickle
-except ImportError:
-    import pickle as pickle
-#
-
 import copy
 import os
 import sys
@@ -605,7 +599,7 @@ class AlignmentTools(AlignmentDataStore):
         #
         authIdx = self._seqAlignLabelIndices[authLabel]
         #
-        self.__conflictMap = {}
+        self.__conflictMap = {}  # pylint: disable=attribute-defined-outside-init
         totalSeqCoodConflict = 0
         for otherIdx in sorted(self._reverseSeqAlignLabelIndices.keys()):
             otherLabel = self._reverseSeqAlignLabelIndices[otherIdx]
@@ -642,10 +636,7 @@ class AlignmentTools(AlignmentDataStore):
             if totalSeqCoodConflict > 0:
                 self.__conflictMap["mismatch"] = totalSeqCoodConflict
             #
-            picklePath = os.path.join(self._sessionPath, "conflict-for-entity-" + self._entityId + ".pic")
-            fb = open(picklePath, "wb")
-            pickle.dump(self.__conflictMap, fb)
-            fb.close()
+            self._missingSeqMap["summary_page"] = self.__conflictMap
         #
         return totalSeqCoodConflict
 
@@ -1128,7 +1119,7 @@ class AlignmentTools(AlignmentDataStore):
                 continue
             #
             if seqType == "xyz":
-                # added 'auth_numbering' as 4th value in seqTuple. See setCoordinateInstanceInfo() method in 
+                # added 'auth_numbering' as 4th value in seqTuple. See setCoordinateInstanceInfo() method in
                 # util/UpdateSequenceDataStoreUtils.py for the definition of all values in coordinate seqTup
                 returnSeqList.append((str(seqTup[0]).upper(), str(i), str(seqTup[6]), str(seqTup[1])))
             else:
@@ -1249,7 +1240,7 @@ class AlignmentTools(AlignmentDataStore):
             finalComment = self.__consolidateConflict(comment, self._seqAlignList[i][authIdx][5], self._seqAlignList[i][refIdx][5])
             self._seqAlignList[i][authIdx][5] = finalComment
             if writeConflictFlag:
-                commentType, commentValue = self._decodeComment(finalComment)
+                _commentType, commentValue = self._decodeComment(finalComment)
                 if commentValue in self.__conflictMap:
                     self.__conflictMap[commentValue] += 1
                 else:
@@ -1518,7 +1509,6 @@ class AlignmentTools(AlignmentDataStore):
         #
         editList = []
         for alignPos in gapList:
-            self._lfh.flush()
             xyzRecord = self._seqAlignList[alignPos][chainIdx]
             #
             currId = self._getResLabelId(
