@@ -139,16 +139,16 @@ class LocalBlastSearchUtils(object):
         if (not self.__dataSetId) or (not self.__entityD):
             return {}
         #
-        autoMatchStatus,rD = self.__getExistingSearchResult()
+        autoMatchStatus, rD = self.__getExistingSearchResult()
         if rD:
-            return autoMatchStatus,rD
+            return autoMatchStatus, rD
         #
-        autoMatchStatus,rD = self.__runBlastSearch()
+        autoMatchStatus, rD = self.__runBlastSearch()
         if rD:
             self.__writeSearchResult(rD)
             # self.__writeBlastSearchResultCifFile(rD)
         #
-        return autoMatchStatus,rD
+        return autoMatchStatus, rD
 
     def __getExistingSearchResult(self):
         """Get prvious blast search result"""
@@ -178,7 +178,7 @@ class LocalBlastSearchUtils(object):
                 or (self.__entitySeq != pickleObj["sequence"])
                 or (len(self.__entityD["PART_LIST"]) != len(pickleObj["part_info"]))
             ):
-                return False,{}
+                return False, {}
             #
             for partNum, fD in enumerate(self.__entityD["PART_LIST"], start=1):
                 if (
@@ -186,7 +186,7 @@ class LocalBlastSearchUtils(object):
                     or (fD["SEQ_NUM_BEG"] != pickleObj["part_info"][partNum][0])
                     or (fD["SEQ_NUM_END"] != pickleObj["part_info"][partNum][1])
                 ):
-                    return False,{}
+                    return False, {}
                 #
             #
             if self.__verbose:
@@ -194,7 +194,7 @@ class LocalBlastSearchUtils(object):
             #
             return self.__getReSortHitInfo(pickleObj["ref_data"])
         #
-        return False,{}
+        return False, {}
 
     def __getReSortHitInfo(self, inD):
         """ """
@@ -216,9 +216,9 @@ class LocalBlastSearchUtils(object):
             if (len(autoMatchList) > 0) and (len(autoMatchList) == len(self.__entityD["PART_LIST"])):
                 autoMatchStatus = True
             #
-            return autoMatchStatus,outD
+            return autoMatchStatus, outD
         except:  # noqa: E722 pylint: disable=bare-except
-            return False,{}
+            return False, {}
         #
 
     def __runBlastSearch(self):
@@ -239,7 +239,7 @@ class LocalBlastSearchUtils(object):
         #
         authRefD = {}
         if not self.__checkPartRange(len(self.__fullOneLetterSeq), self.__entityD["PART_LIST"]):
-            return False,authRefD
+            return False, authRefD
         #
         foundPerfectMatch = True
         partDataList = []
@@ -264,20 +264,22 @@ class LocalBlastSearchUtils(object):
                 #
                 continue
             #
-            # Skip blast search for UNK sequence DAOTHER-3639
+            # Skip blast search for poly-UNK/ALA sequence (DAOTHER-3639 & DAOTHER-8135)
             countUNK = 0
+            countALA = 0
             countTotal = 0
             for oneLetterCode in self.__fullOneLetterSeq[(int(seqNumBeg) - 1) : int(seqNumEnd)]:
                 if oneLetterCode == "X":
                     countUNK += 1
+                elif oneLetterCode == "A":
+                    countALA += 1
                 #
                 countTotal += 1
             #
-            if (10 * countUNK) > (9 * countTotal):
+            if ((10 * countUNK) > (9 * countTotal)) or (self.__seqType.startswith("polypeptide") and ((10 * countALA) > (9 * countTotal))):
                 if self.__verbose:
-                    self.__lfh.write(
-                        "+LocalBlastSearchUtils.__runBlastSearch() skipping unknown sequence part %r type %r BegNum %r EndNum %r\n" % (seqPartId, seqPartType, seqNumBeg, seqNumEnd)
-                    )
+                    self.__lfh.write("+LocalBlastSearchUtils.__runBlastSearch() skipping unknown/poly-ALA sequence part %r type %r BegNum %r EndNum %r\n" %
+                                     (seqPartId, seqPartType, seqNumBeg, seqNumEnd))
                 #
                 continue
             #
@@ -310,8 +312,8 @@ class LocalBlastSearchUtils(object):
                     #
                 #
             #
-            autoMatchStatus,authHitList = self.__fetchAuthProvidedRefSequence(searchSequence, seqNumBeg, seqNumEnd, str(partNum), taxId, mutationList, \
-                                                                              len(self.__entityD["PART_LIST"]))
+            autoMatchStatus, authHitList = self.__fetchAuthProvidedRefSequence(searchSequence, seqNumBeg, seqNumEnd, str(partNum), taxId, mutationList,
+                                                                               len(self.__entityD["PART_LIST"]))
             if not autoMatchStatus:
                 foundPerfectMatch = False
             #
@@ -331,7 +333,7 @@ class LocalBlastSearchUtils(object):
             blastDataList.append((str(partNum), searchSequence, seqNumBeg, seqNumEnd, taxId, xmlFilePath))
         #
         if not partDataList:
-            return foundPerfectMatch,authRefD
+            return foundPerfectMatch, authRefD
         #
         rD = {}
         try:
@@ -347,7 +349,7 @@ class LocalBlastSearchUtils(object):
             for partTup in partDataList:
                 hitList = []
                 if os.access(partTup[5], os.F_OK):
-                    hitList = self.__readBlastResultXmlFile(seqNumBeg=partTup[2], seqNumEnd=partTup[3], seqPartId=partTup[0], authTaxId=partTup[4], \
+                    hitList = self.__readBlastResultXmlFile(seqNumBeg=partTup[2], seqNumEnd=partTup[3], seqPartId=partTup[0], authTaxId=partTup[4],
                                                             blastResultXmlPath=partTup[5])
                 #
                 if hitList:
@@ -397,12 +399,12 @@ class LocalBlastSearchUtils(object):
                 self.__lfh.write("+LocalBlastSearchUtils.__runBlastSearch() search for entity %r failed\n" % self.__entityId)
             #
         #
-        return foundPerfectMatch,rD
+        return foundPerfectMatch, rD
 
     def __fetchAuthProvidedRefSequence(self, sequence, seqNumBeg, seqNumEnd, seqPartId, taxId, mutationList, partNumbers):
         """Fetch reference sequence based on author provided ref IDs"""
         if (not self.__authRefDataList) or (len(self.__authRefDataList) > partNumbers):
-            return False,[]
+            return False, []
         #
         refData = []
         if partNumbers > 1:
@@ -416,10 +418,10 @@ class LocalBlastSearchUtils(object):
             refData = self.__authRefDataList[0]
         #
         if not refData:
-            return False,[]
+            return False, []
         #
         fetchUtil = FetchReferenceSequenceUtils(siteId=self.__siteId, seqReferenceData=self.__srd, verbose=self.__verbose, log=self.__lfh)
-        autoMatchStatus,hitD = fetchUtil.fetchReferenceSequenceWithSeqMatch(refData[0], refData[1], refData[2], taxId, sequence, seqNumBeg, mutationList)
+        autoMatchStatus, hitD = fetchUtil.fetchReferenceSequenceWithSeqMatch(refData[0], refData[1], refData[2], taxId, sequence, seqNumBeg, mutationList)
         if hitD:
             hitD["beg_seq_num"] = seqNumBeg
             hitD["end_seq_num"] = seqNumEnd
@@ -434,12 +436,12 @@ class LocalBlastSearchUtils(object):
                 if autoMatchStatus:
                     hitD["auto_match_status"] = True
                 #
-                return autoMatchStatus,[hitD]
+                return autoMatchStatus, [hitD]
             else:
                 self.__lfh.write("+LocalBlastSearchUtils.__fetchAuthProvidedRefSequence() get sequence alignment index error: %s\n" % error)
             #
         #
-        return False,[]
+        return False, []
 
     def __writeSearchResult(self, rD):
         """Write out the current search result pickle file"""
@@ -566,6 +568,7 @@ class LocalBlastSearchUtils(object):
         bpr = BlastPlusReader(verbose=self.__verbose, log=self.__lfh)
         if self.__seqType == "polyribonucleotide":
             bpr.setSequenceType(self.__seqType)
+        #
         searchHitList = bpr.readFile(filePath=blastResultXmlPath)
         #
         if self.__seqType in ["polypeptide(L)", "polypeptide(D)", "polypeptide"]:
@@ -595,8 +598,14 @@ class LocalBlastSearchUtils(object):
             #
             if self.__verbose:
                 self.__lfh.write("+LocalBlastSearchUtils.__readBlastResultXmlFile() Fetch sequence database entries for %d filtered reference idcodes\n" % len(idCodeList))
+            #
             if len(idCodeList) > 0:
-                unpD = fetchUniProt(idTupleList=idCodeList, verbose=self.__verbose, log=self.__lfh)
+                try:
+                    unpD = fetchUniProt(idTupleList=idCodeList, verbose=self.__verbose, log=self.__lfh)
+                except:  # noqa: E722 pylint: disable=bare-except
+                    traceback.print_exc(file=self.__lfh)
+                    self.__lfh.flush()
+                #
                 for hit in searchHitList:
                     acId = None
                     isIso = False
@@ -624,9 +633,11 @@ class LocalBlastSearchUtils(object):
                         elif isIso and ((hit["db_accession"], start, end) in unpD):
                             dd = unpD[(hit["db_accession"], start, end)]
                         #
-                        for (k, v) in dd.items():
-                            if (k != "sequence") and (k not in hit):
-                                hit[k] = v
+                        if dd:
+                            for (k, v) in dd.items():
+                                if (k != "sequence") and ((k not in hit) or (v and (k in ("name", "source_scientific", "strain", "taxonomy_id", "gene")))):
+                                    hit[k] = v
+                                #
                             #
                         #
                         hitList.append(hit)
@@ -722,6 +733,7 @@ class LocalBlastSearchUtils(object):
         highest_identity_score_with_taxid_match = 0
         lowest_identity_score_with_taxid_match = 101
         lowest_identity_score_with_refid_match = 101
+        has_author_provided_id = False
         for i, hit in enumerate(hitList):
             if "non_isoform_score" not in hit:
                 hit["non_isoform_score"] = 1
@@ -740,20 +752,20 @@ class LocalBlastSearchUtils(object):
                     hit["db_score"] = 0
                 #
             #
-            if self.__authRefIdList and ((hit["db_code"].strip().upper() in self.__authRefIdList) or (hit["db_accession"].strip().upper() in \
+            if self.__authRefIdList and ((hit["db_code"].strip().upper() in self.__authRefIdList) or (hit["db_accession"].strip().upper() in
                self.__authRefIdList) or (hit["db_isoform"].strip().upper() in self.__authRefIdList)):
                 if hit["identity_score"] < lowest_identity_score_with_refid_match:
                     lowest_identity_score_with_refid_match = hit["identity_score"]
                 #
-                hit["auto_match_status"] = True
                 hit["author_provided_id"] = True
+                has_author_provided_id = True
                 hit["code_score"] = 1
             else:
                 hit["code_score"] = 0
             #
             targetAncestorD = {}
             taxonomy_id = ""
-            if "taxonomy_id" in hit:
+            if ("taxonomy_id" in hit) and hit["taxonomy_id"]:
                 taxonomy_id = hit["taxonomy_id"]
                 targetAncestorD = self.__taxUtils.getAncestors(hit["taxonomy_id"])
             #
@@ -795,24 +807,40 @@ class LocalBlastSearchUtils(object):
                 #
             #
         #
-        start_index = 0
         cutoff_identity_score = 0
         if highest_identity_score_with_taxid_match > 0:
             cutoff_identity_score = 0.85 * highest_identity_score_with_taxid_match
             if lowest_identity_score_with_refid_match < cutoff_identity_score:
-                cutoff_identity_score = lowest_identity_score_with_refid_match
+                cutoff_identity_score = lowest_identity_score_with_refid_match - 0.1
             #
             if lowest_identity_score_with_taxid_match < cutoff_identity_score:
-                cutoff_identity_score = lowest_identity_score_with_taxid_match
+                cutoff_identity_score = lowest_identity_score_with_taxid_match - 0.1
             #
         #
         # The highest score hit is at the bottom of the list.
         #
         hitList.sort(key=itemgetter("identity_score", "taxid_match", "code_score", "db_score", "non_isoform_score"))
         #
+        # reorder list if found author provided reference id
+        #
+        if has_author_provided_id and (len(hitList) > 2):
+            idx = -1
+            for i, hit in enumerate(hitList):
+                if ("author_provided_id" in hit) and hit["author_provided_id"]:
+                    idx = i
+                #
+            #
+            if (idx >= 0) and (idx < (len(hitList) - 2)):
+                hitList.insert(-1, hitList.pop(idx))
+            #
+        #
+        start_index = 0
         first = True
         for i, hit in enumerate(hitList):
             hit["sort_order"] = str(i + 1)
+            if ("author_provided_id" in hit) and hit["author_provided_id"]:
+                continue
+            #
             if first and (hit["identity_score"] > cutoff_identity_score):
                 start_index = i
                 first = False
@@ -870,7 +898,9 @@ class LocalBlastSearchUtils(object):
             for blastD in blastHitList:
                 if ("db_accession" in authD) and ("db_isoform" in authD) and ("db_accession" in blastD) and ("db_isoform" in blastD) and \
                    (authD["db_accession"] == blastD["db_accession"]) and (authD["db_isoform"] == blastD["db_isoform"]):
-                    blastD["auto_match_status"] = True
+                    if ("auto_match_status" in authD) and authD["auto_match_status"]:
+                        blastD["auto_match_status"] = True
+                    #
                     found = True
                     break
                 #
@@ -879,24 +909,12 @@ class LocalBlastSearchUtils(object):
                 mergedHitList.append(authD)
             #
         #
-        mergedHitList.extend(blastHitList)
-        start_index, finalList = self.__sortHitList(mergedHitList, authTaxId, True)
-        if ("auto_match_status" in finalList[-1]) and finalList[-1]["auto_match_status"]:
-            return finalList[-1:]
-        else:
-            mergedHitList = []
-            autoIdx = 0
-            for (idx,hitD) in enumerate(finalList, start=1):
-                if ("auto_match_status" in hitD) and hitD["auto_match_status"]:
-                    mergedHitList.append(hitD)
-                    autoIdx = idx
-                #
-            #
-            if autoIdx < len(finalList):
-                mergedHitList.append(finalList[-1])
-            #
-            return mergedHitList
+        if not mergedHitList:
+            return blastHitList
         #
+        mergedHitList.extend(blastHitList)
+        _start_index, finalList = self.__sortHitList(mergedHitList, authTaxId, True)
+        return finalList
 
     def getMultiSeqAlignmentProcess(self, dataList, procName, optionsD, workingDir):  # pylint: disable=unused-argument
         """Get Auth/Ref sequence alignments MultiProcUtil API"""
